import { IGolangPluginConfig } from './config';
import { DocumentNode, GraphQLSchema } from 'graphql';
/**
 * GolangGenerator is a class that you instanciate with a GraphQL schema
 * and an optional configuration. You can then call its method `generate`
 * to generate Golang code.
 */
export declare class GolangGenerator {
    /**
     * The configuration used when generating Golang code.
     */
    readonly config: IGolangPluginConfig;
    /**
     * The GraphQL schema used to generate Golang code.
     */
    readonly schema: GraphQLSchema;
    private _templateEngine;
    private _templateOperation;
    /**
     * Map GraphQL type to their Golang format.
     */
    readonly types: {
        [key: string]: string;
    };
    /**
     * Map GraphQL scalar types to Golang types.
     */
    readonly scalars: {
        [key: string]: string;
    };
    private _enums;
    private _inputs;
    private _objects;
    constructor(schema: GraphQLSchema, config?: IGolangPluginConfig);
    generate(documents?: DocumentNode[]): string;
    /**
     * Format a name for Golang.
     * @param name - Name to format.
     */
    private _formatName;
    /**
     * Generate Golang package header.
     */
    private _generatePackage;
    /**
     * Generate Golang imports for operations.
     */
    private _generateImports;
    /**
     * Generate a named comment section.
     * @param name - Name of the section.
     */
    private _generateSection;
    /**
     * Generate the Golang types from schema.
     */
    private _generateSchema;
    private _generateScalars;
    private _generateEnums;
    private _generateInputs;
    private _generateObjects;
    /**
     * Generate a Golang struct's field.
     * @param name - Name of the GraphQL field.
     * @param type - Type of the GraphQL field.
     */
    private _generateField;
    /**
     *
     * @param type - TypeNode contains a GraphQL type.
     * @param fieldName - GraphQL field's name for the Golang's json annotation.
     * @param prefix - String accumulator to add to result when recursion is done.
     * @param nonNull - Boolean accumulator to determine if type must be a pointer.
     */
    private _generateFieldType;
    /**
     * Generate operations code from a GraphQL document.
     * @param document - Document to get the operations from.
     */
    private _generateOperations;
    /**
     * Generate Golang `type ${name}Variables struct {...}`.
     * @param name - Name of the operation. Must be formatted for Golang.
     * @param variableDefinitions - GraphQL variables to generate Golang fields from.
     */
    private _generateOperationVariables;
    /**
     * Generates all Golang code for an operation except `type ${name}Variables`
     * and `type ${name}Response`.
     * @param name - Name of the operation. Must be formatted for Golang.
     * @param operation - String version of the operation.
     * @param hasVariables - Whether the operation uses a `${name}Variables` or not.
     */
    private _generateOperationCode;
}
